@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -47,6 +47,7 @@ try:
     import feedparser
     import configobj
     import cherrypy
+    import cheroot.errors
     import portend
     import cryptography
     import chardet
@@ -64,7 +65,7 @@ import sabnzbd
 import sabnzbd.lang
 import sabnzbd.interface
 from sabnzbd.constants import (
-    DEF_TIMEOUT,
+    DEF_NETWORKING_TIMEOUT,
     DEF_LOG_ERRFILE,
     DEF_MAIN_TMPL,
     DEF_STD_WEB_DIR,
@@ -83,7 +84,6 @@ from sabnzbd.constants import (
 )
 import sabnzbd.newsunpack
 from sabnzbd.misc import (
-    check_latest_version,
     exit_sab,
     split_host,
     create_https_certificates,
@@ -104,8 +104,7 @@ import sabnzbd.config as config
 import sabnzbd.cfg
 import sabnzbd.notifier as notifier
 import sabnzbd.zconfig
-from sabnzbd.getipaddress import localipv4, publicipv4, ipv6, dnslookup
-from sabnzbd.utils.getperformance import getpystone, getcpu
+from sabnzbd.getipaddress import local_ipv4
 import sabnzbd.utils.ssdp as ssdp
 
 try:
@@ -171,7 +170,8 @@ class GUIHandler(logging.Handler):
         # This prevents endless looping if the notification service itself throws an error/warning
         # We don't check based on message content, because if it includes a timestamp it's not unique
         if not any(
-            stored_warning["origin"] == warning["origin"] and stored_warning["time"] + DEF_TIMEOUT > time.time()
+            stored_warning["origin"] == warning["origin"]
+            and stored_warning["time"] + DEF_NETWORKING_TIMEOUT > time.time()
             for stored_warning in self.store
         ):
             if record.levelno == logging.WARNING:
@@ -244,7 +244,7 @@ def print_version():
             """
 %s-%s
 
-Copyright (C) 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+(C) Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
 SABnzbd comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions. It is licensed under the
@@ -298,14 +298,14 @@ def daemonize():
         os.dup2(f.fileno(), sys.stderr.fileno())
 
 
-def abort_and_show_error(browserhost, cherryport, err=""):
+def abort_and_show_error(browserhost, web_port, err=""):
     """Abort program because of CherryPy troubles"""
     logging.error(T("Failed to start web-interface") + " : " + str(err))
     if not sabnzbd.DAEMON:
         if "49" in err:
-            panic_host(browserhost, cherryport)
+            panic_host(browserhost, web_port)
         else:
-            panic_port(browserhost, cherryport)
+            panic_port(browserhost, web_port)
     sabnzbd.halt()
     exit_sab(2)
 
@@ -448,7 +448,8 @@ def print_modules():
 
     if sabnzbd.WIN32 and sabnzbd.newsunpack.MULTIPAR_COMMAND:
         logging.info("MultiPar binary... found (%s)", sabnzbd.newsunpack.MULTIPAR_COMMAND)
-    elif sabnzbd.newsunpack.PAR2_COMMAND:
+
+    if sabnzbd.newsunpack.PAR2_COMMAND:
         logging.info("par2 binary... found (%s)", sabnzbd.newsunpack.PAR2_COMMAND)
     else:
         logging.error(T("par2 binary... NOT found!"))
@@ -470,18 +471,12 @@ def print_modules():
         # Do not allow downloading
         sabnzbd.NO_DOWNLOADING = True
 
-    # If available, we prefer 7zip over unzip
     if sabnzbd.newsunpack.SEVENZIP_COMMAND:
         logging.info("7za binary... found (%s)", sabnzbd.newsunpack.SEVENZIP_COMMAND)
         if not (sabnzbd.WIN32 or sabnzbd.MACOS):
             logging.info("7za binary version %s", sabnzbd.newsunpack.SEVENZIP_VERSION)
     else:
-        logging.info(T("7za binary... NOT found!"))
-
-        if sabnzbd.newsunpack.ZIP_COMMAND:
-            logging.info("unzip binary... found (%s)", sabnzbd.newsunpack.ZIP_COMMAND)
-        else:
-            logging.info(T("unzip binary... NOT found!"))
+        logging.warning(T("7za binary... NOT found!"))
 
     if not sabnzbd.WIN32:
         if sabnzbd.newsunpack.NICE_COMMAND:
@@ -536,19 +531,19 @@ def check_resolve(host):
     return True
 
 
-def get_webhost(cherryhost, cherryport, https_port):
+def get_webhost(web_host, web_port, https_port):
     """Determine the webhost address and port,
     return (host, port, browserhost)
     """
-    if cherryhost == "0.0.0.0" and not check_resolve("127.0.0.1"):
-        cherryhost = ""
-    elif cherryhost == "::" and not check_resolve("::1"):
-        cherryhost = ""
+    if web_host == "0.0.0.0" and not check_resolve("127.0.0.1"):
+        web_host = ""
+    elif web_host == "::" and not check_resolve("::1"):
+        web_host = ""
 
-    if cherryhost is None:
-        cherryhost = sabnzbd.cfg.cherryhost()
+    if web_host is None:
+        web_host = sabnzbd.cfg.web_host()
     else:
-        sabnzbd.cfg.cherryhost.set(cherryhost)
+        sabnzbd.cfg.web_host.set(web_host)
 
     # Get IP address, but discard APIPA/IPV6
     # If only APIPA's or IPV6 are found, fall back to localhost
@@ -560,10 +555,10 @@ def get_webhost(cherryhost, cherryport, https_port):
         # Hostname does not resolve
         try:
             # Valid user defined name?
-            info = socket.getaddrinfo(cherryhost, None)
+            info = socket.getaddrinfo(web_host, None)
         except socket.error:
-            if not is_localhost(cherryhost):
-                cherryhost = "0.0.0.0"
+            if not is_localhost(web_host):
+                web_host = "0.0.0.0"
             try:
                 info = socket.getaddrinfo(localhost, None)
             except socket.error:
@@ -580,79 +575,75 @@ def get_webhost(cherryhost, cherryport, https_port):
             hostip = ip
 
     # A blank host will use the local ip address
-    if cherryhost == "":
+    if web_host == "":
         if ipv6 and ipv4:
             # To protect Firefox users, use numeric IP
-            cherryhost = hostip
+            web_host = hostip
             browserhost = hostip
         else:
-            cherryhost = socket.gethostname()
-            browserhost = cherryhost
+            web_host = socket.gethostname()
+            browserhost = web_host
 
     # 0.0.0.0 will listen on all ipv4 interfaces (no ipv6 addresses)
-    elif cherryhost == "0.0.0.0":
+    elif web_host == "0.0.0.0":
         # Just take the gamble for this
-        cherryhost = "0.0.0.0"
+        web_host = "0.0.0.0"
         browserhost = localhost
 
     # :: will listen on all ipv6 interfaces (no ipv4 addresses)
-    elif cherryhost in ("::", "[::]"):
-        cherryhost = cherryhost.strip("[").strip("]")
+    elif web_host in ("::", "[::]"):
+        web_host = web_host.strip("[").strip("]")
         # Assume '::1' == 'localhost'
         browserhost = localhost
 
     # IPV6 address
-    elif "[" in cherryhost or ":" in cherryhost:
-        browserhost = cherryhost
+    elif "[" in web_host or ":" in web_host:
+        browserhost = web_host
 
     # IPV6 numeric address
-    elif cherryhost.replace(".", "").isdigit():
+    elif web_host.replace(".", "").isdigit():
         # IPV4 numerical
-        browserhost = cherryhost
+        browserhost = web_host
 
-    elif cherryhost == localhost:
-        cherryhost = localhost
+    elif web_host == localhost:
+        web_host = localhost
         browserhost = localhost
 
     else:
         # If on APIPA, use numerical IP, to help FireFoxers
         if ipv6 and ipv4:
-            cherryhost = hostip
-        browserhost = cherryhost
+            web_host = hostip
+        browserhost = web_host
 
         # Some systems don't like brackets in numerical ipv6
         if sabnzbd.MACOS:
-            cherryhost = cherryhost.strip("[]")
+            web_host = web_host.strip("[]")
         else:
             try:
-                socket.getaddrinfo(cherryhost, None)
+                socket.getaddrinfo(web_host, None)
             except socket.error:
-                cherryhost = cherryhost.strip("[]")
+                web_host = web_host.strip("[]")
 
-    if ipv6 and ipv4 and not is_localhost(browserhost):
-        sabnzbd.AMBI_LOCALHOST = True
-        logging.info("IPV6 has priority on this system, potential Firefox issue")
-
-    if ipv6 and ipv4 and cherryhost == "" and sabnzbd.WIN32:
+    if ipv6 and ipv4 and web_host == "" and sabnzbd.WIN32:
         helpful_warning(T("Please be aware the 0.0.0.0 hostname will need an IPv6 address for external access"))
 
-    if cherryhost == "localhost" and not sabnzbd.WIN32 and not sabnzbd.MACOS:
+    if web_host == "localhost" and not sabnzbd.WIN32 and not sabnzbd.MACOS:
         # On the Ubuntu family, localhost leads to problems for CherryPy
         ips = ip_extract()
         if "127.0.0.1" in ips and "::1" in ips:
-            cherryhost = "127.0.0.1"
+            web_host = "127.0.0.1"
             if ips[0] != "127.0.0.1":
                 browserhost = "127.0.0.1"
 
     # This is to please Chrome on macOS
-    if cherryhost == "localhost" and sabnzbd.MACOS:
-        cherryhost = "127.0.0.1"
+    if web_host == "localhost" and sabnzbd.MACOS:
+        web_host = "127.0.0.1"
         browserhost = "localhost"
 
-    if cherryport is None:
-        cherryport = sabnzbd.cfg.cherryport.get_int()
+    if web_port is None:
+        web_port = sabnzbd.cfg.web_port.get_int()
     else:
-        sabnzbd.cfg.cherryport.set(str(cherryport))
+        sabnzbd.cfg.web_port.set(str(web_port))
 
     if https_port is None:
         https_port = sabnzbd.cfg.https_port.get_int()
@@ -661,12 +652,12 @@ def get_webhost(cherryhost, cherryport, https_port):
         # if the https port was specified, assume they want HTTPS enabling also
         sabnzbd.cfg.enable_https.set(True)
 
-    if cherryport == https_port and sabnzbd.cfg.enable_https():
+    if web_port == https_port and sabnzbd.cfg.enable_https():
         sabnzbd.cfg.enable_https.set(False)
         # Should have a translated message, but that's not available yet
         logging.error(T("HTTP and HTTPS ports cannot be the same"))
 
-    return cherryhost, cherryport, browserhost, https_port
+    return web_host, web_port, browserhost, https_port
 
 
 def attach_server(host, port, cert=None, key=None, chain=None):
@@ -761,26 +752,9 @@ def commandline_handler():
     serv_opts = [os.path.normpath(os.path.abspath(sys.argv[0]))]
     upload_nzbs = []
 
-    # macOS binary: get rid of the weird -psn_0_123456 parameter
-    for arg in sys.argv:
-        if arg.startswith("-psn_"):
-            sys.argv.remove(arg)
-            break
-
-    # Ugly hack to remove the extra "SABnzbd*" parameter the Windows binary
-    # gets when it's restarted
-    if len(sys.argv) > 1 and "sabnzbd" in sys.argv[1].lower() and not sys.argv[1].startswith("-"):
-        slice_start = 2
-    else:
-        slice_start = 1
-
-    # Prepend options from env-variable to options
-    info = os.environ.get("SABnzbd", "").split()
-    info.extend(sys.argv[slice_start:])
-
     try:
         opts, args = getopt.getopt(
-            info,
+            sys.argv[1:],
             "phdvncwl:s:f:t:b:2:",
             [
                 "pause",
@@ -863,13 +837,13 @@ def main():
 
     autobrowser = None
     autorestarted = False
-    sabnzbd.MY_FULLNAME = sys.argv[0]
+    sabnzbd.MY_FULLNAME = __file__
     sabnzbd.MY_NAME = os.path.basename(sabnzbd.MY_FULLNAME)
     fork = False
     pause = False
     inifile = None
-    cherryhost = None
-    cherryport = None
+    web_host = None
+    web_port = None
     https_port = None
     cherrypylogging = None
     clean_up = False
@@ -907,14 +881,11 @@ def main():
         elif opt in ("-t", "--templates"):
             web_dir = arg
         elif opt in ("-s", "--server"):
-            (cherryhost, cherryport) = split_host(arg)
+            (web_host, web_port) = split_host(arg)
         elif opt in ("-n", "--nobrowser"):
             autobrowser = False
         elif opt in ("-b", "--browser"):
-            try:
-                autobrowser = bool(int(arg))
-            except ValueError:
-                autobrowser = True
+            autobrowser = sabnzbd.misc.bool_conv(arg)
         elif opt == "--autorestarted":
             autorestarted = True
         elif opt in ("-c", "--clean"):
@@ -931,6 +902,7 @@ def main():
                 exit_sab(1)
         elif opt == "--console":
             console_logging = True
+            sabnzbd.RESTART_ARGS.append(opt)
         elif opt in ("-v", "--version"):
             print_version()
             exit_sab(0)
@@ -975,7 +947,7 @@ def main():
     org_dir = os.getcwd()
 
     # Need console logging if requested, for SABnzbd.py and SABnzbd-console.exe
-    console_logging = console_logging or sabnzbd.MY_NAME.lower().find("-console") > 0 or not hasattr(sys, "frozen")
+    console_logging = console_logging or sys.executable.endswith("console.exe") or not hasattr(sys, "frozen")
     console_logging = console_logging and not sabnzbd.DAEMON
 
     LOGLEVELS = (logging.FATAL, logging.WARNING, logging.INFO, logging.DEBUG)
@@ -1032,24 +1004,24 @@ def main():
         sabnzbd.cfg.ipv6_hosting.set(ipv6_hosting)
 
     # Determine web host address
-    cherryhost, cherryport, browserhost, https_port = get_webhost(cherryhost, cherryport, https_port)
+    web_host, web_port, browserhost, https_port = get_webhost(web_host, web_port, https_port)
     enable_https = sabnzbd.cfg.enable_https()
 
     # When this is a daemon, just check and bail out if port in use
     if sabnzbd.DAEMON:
         if enable_https and https_port:
             try:
-                portend.free(cherryhost, https_port, timeout=0.05)
+                portend.free(web_host, https_port, timeout=0.05)
             except IOError:
-                abort_and_show_error(browserhost, cherryport)
+                abort_and_show_error(browserhost, web_port)
             except:
-                abort_and_show_error(browserhost, cherryport, "49")
+                abort_and_show_error(browserhost, web_port, "49")
         try:
-            portend.free(cherryhost, cherryport, timeout=0.05)
+            portend.free(web_host, web_port, timeout=0.05)
         except IOError:
-            abort_and_show_error(browserhost, cherryport)
+            abort_and_show_error(browserhost, web_port)
         except:
-            abort_and_show_error(browserhost, cherryport, "49")
+            abort_and_show_error(browserhost, web_port, "49")
 
     # Windows instance is reachable through registry
     url = None
@@ -1060,7 +1032,7 @@ def main():
 
     # SSL
     if enable_https:
-        port = https_port or cherryport
+        port = https_port or web_port
         try:
             portend.free(browserhost, port, timeout=0.05)
         except IOError as error:
@@ -1072,7 +1044,7 @@ def main():
                 if new_instance or not check_for_sabnzbd(url, upload_nzbs, autobrowser):
                     # Bail out if we have fixed our ports after first start-up
                     if sabnzbd.cfg.fixed_ports():
-                        abort_and_show_error(browserhost, cherryport)
+                        abort_and_show_error(browserhost, web_port)
                     # Find free port to bind
                     newport = find_free_port(browserhost, port)
                     if newport > 0:
@@ -1082,34 +1054,34 @@ def main():
                             sabnzbd.cfg.https_port.set(newport)
                         else:
                             # In case HTTPS == HTTP port
-                            cherryport = newport
-                            sabnzbd.cfg.cherryport.set(newport)
+                            web_port = newport
+                            sabnzbd.cfg.web_port.set(newport)
         except:
             # Something else wrong, probably badly specified host
-            abort_and_show_error(browserhost, cherryport, "49")
+            abort_and_show_error(browserhost, web_port, "49")
 
     # NonSSL check if there's no HTTPS or we only use 1 port
     if not (enable_https and not https_port):
         try:
-            portend.free(browserhost, cherryport, timeout=0.05)
+            portend.free(browserhost, web_port, timeout=0.05)
         except IOError as error:
             if str(error) == "Port not bound.":
                 pass
             else:
                 if not url:
-                    url = "http://%s:%s%s/api?" % (browserhost, cherryport, sabnzbd.cfg.url_base())
+                    url = "http://%s:%s%s/api?" % (browserhost, web_port, sabnzbd.cfg.url_base())
                 if new_instance or not check_for_sabnzbd(url, upload_nzbs, autobrowser):
                     # Bail out if we have fixed our ports after first start-up
                     if sabnzbd.cfg.fixed_ports():
-                        abort_and_show_error(browserhost, cherryport)
+                        abort_and_show_error(browserhost, web_port)
                     # Find free port to bind
-                    port = find_free_port(browserhost, cherryport)
+                    port = find_free_port(browserhost, web_port)
                     if port > 0:
-                        sabnzbd.cfg.cherryport.set(port)
-                        cherryport = port
+                        sabnzbd.cfg.web_port.set(port)
+                        web_port = port
         except:
             # Something else wrong, probably badly specified host
-            abort_and_show_error(browserhost, cherryport, "49")
+            abort_and_show_error(browserhost, web_port, "49")
 
     # We found a port, now we never check again
     sabnzbd.cfg.fixed_ports.set(True)
@@ -1121,8 +1093,7 @@ def main():
         sys.exit(1)
 
     if clean_up:
-        xlist = globber_full(logdir)
-        for x in xlist:
+        for x in globber_full(logdir):
             if RSS_FILE_NAME not in x:
                 try:
                     os.remove(x)
@@ -1232,23 +1203,13 @@ def main():
             logging.warning(T("Could not load additional certificates from certifi package"))
             logging.info("Traceback: ", exc_info=True)
 
-    # Extra startup info
+    # List the number of certificates available (can take up to 1.5 seconds)
     if sabnzbd.cfg.log_level() > 1:
-        # List the number of certificates available (can take up to 1.5 seconds)
         logging.debug("Available certificates = %s", repr(ssl.create_default_context().cert_store_stats()))
 
-        # List networking
-        localipv4()
-        publicipv4()
-        ipv6()
-        dnslookup()
-
-        # Measure basic system performance measured by pystone and - if possible - CPU model
-        getpystone()
-        getcpu()
-
     logging.info("Using INI file %s", inifile)
 
+    # Store auto-browser setting from command line
     if autobrowser is not None:
         sabnzbd.cfg.autobrowser.set(autobrowser)
 
@@ -1314,29 +1275,29 @@ def main():
     # Starting of the webserver
     # Determine if this system has multiple definitions for 'localhost'
     hosts = all_localhosts()
-    multilocal = len(hosts) > 1 and cherryhost in ("localhost", "0.0.0.0")
+    multilocal = len(hosts) > 1 and web_host in ("localhost", "0.0.0.0")
 
     # For 0.0.0.0 CherryPy will always pick IPv4, so make sure the secondary localhost is IPv6
-    if multilocal and cherryhost == "0.0.0.0" and hosts[1] == "127.0.0.1":
+    if multilocal and web_host == "0.0.0.0" and hosts[1] == "127.0.0.1":
         hosts[1] = "::1"
 
     # The Windows binary requires numeric localhost as primary address
-    if cherryhost == "localhost":
-        cherryhost = hosts[0]
+    if web_host == "localhost":
+        web_host = hosts[0]
 
     if enable_https:
         if https_port:
             # Extra HTTP port for primary localhost
-            attach_server(cherryhost, cherryport)
+            attach_server(web_host, web_port)
             if multilocal:
                 # Extra HTTP port for secondary localhost
-                attach_server(hosts[1], cherryport)
+                attach_server(hosts[1], web_port)
                 # Extra HTTPS port for secondary localhost
                 attach_server(hosts[1], https_port, https_cert, https_key, https_chain)
-            cherryport = https_port
+            web_port = https_port
         elif multilocal:
             # Extra HTTPS port for secondary localhost
-            attach_server(hosts[1], cherryport, https_cert, https_key, https_chain)
+            attach_server(hosts[1], web_port, https_cert, https_key, https_chain)
 
         cherrypy.config.update(
             {
@@ -1348,7 +1309,7 @@ def main():
         )
     elif multilocal:
         # Extra HTTP port for secondary localhost
-        attach_server(hosts[1], cherryport)
+        attach_server(hosts[1], web_port)
 
     if no_login:
         sabnzbd.cfg.username.set("")
@@ -1371,10 +1332,9 @@ def main():
     cherrypy.config.update(
         {
             "server.environment": "production",
-            "server.socket_host": cherryhost,
-            "server.socket_port": cherryport,
+            "server.socket_host": web_host,
+            "server.socket_port": web_port,
             "server.shutdown_timeout": 0,
-            "log.screen": False,
             "engine.autoreload.on": False,
             "tools.encode.on": True,
             "tools.gzip.on": True,
@@ -1385,14 +1345,19 @@ def main():
         }
     )
 
+    # Catch shutdown errors that can break cherrypy/cheroot
+    # See https://github.com/cherrypy/cheroot/issues/710
+    try:
+        cheroot.errors.acceptable_sock_shutdown_exceptions += (OSError,)
+    except AttributeError:
+        pass
+
     # Do we want CherryPy Logging? Cannot be done via the config
+    cherrypy.log.screen = False
+    cherrypy.log.access_log.propagate = False
     if cherrypylogging:
         sabnzbd.WEBLOGFILE = os.path.join(logdir, DEF_LOG_CHERRY)
-        cherrypy.log.screen = True
-        cherrypy.log.access_log.propagate = True
         cherrypy.log.access_file = str(sabnzbd.WEBLOGFILE)
-    else:
-        cherrypy.log.access_log.propagate = False
 
     # Force mimetypes (OS might overwrite them)
     forced_mime_types = {"css": "text/css", "js": "application/javascript"}
@@ -1436,7 +1401,7 @@ def main():
 
     # Set authentication for CherryPy
     sabnzbd.interface.set_auth(cherrypy.config)
-    logging.info("Starting web-interface on %s:%s", cherryhost, cherryport)
+    logging.info("Starting web-interface on %s:%s", web_host, web_port)
 
     sabnzbd.cfg.log_level.callback(guard_loglevel)
 
@@ -1446,7 +1411,7 @@ def main():
         # Since the webserver is started by cherrypy in a separate thread, we can't really catch any
         # start-up errors. This try/except only catches very few errors, the rest is only shown in the console.
         logging.error(T("Failed to start web-interface: "), exc_info=True)
-        abort_and_show_error(browserhost, cherryport)
+        abort_and_show_error(browserhost, web_port)
 
     # Create a record of the active cert/key/chain files, for use with config.create_config_backup()
     if enable_https:
@@ -1454,24 +1419,18 @@ def main():
             if full_path := getattr(sabnzbd.cfg, setting).get_path():
                 sabnzbd.CONFIG_BACKUP_HTTPS_OK.append(full_path)
 
-    if sabnzbd.WIN32:
-        if enable_https:
-            mode = "s"
-        else:
-            mode = ""
-        api_url = "http%s://%s:%s%s/api?apikey=%s" % (
-            mode,
-            browserhost,
-            cherryport,
-            sabnzbd.cfg.url_base(),
-            sabnzbd.cfg.api_key(),
-        )
+    # Set URL for browser
+    if enable_https:
+        sabnzbd.BROWSER_URL = "https://%s:%s%s" % (browserhost, web_port, sabnzbd.cfg.url_base())
+    else:
+        sabnzbd.BROWSER_URL = "http://%s:%s%s" % (browserhost, web_port, sabnzbd.cfg.url_base())
 
-        # Write URL directly to registry
-        set_connection_info(api_url)
+    if sabnzbd.WIN32:
+        # Write URL for uploads and version check directly to registry
+        set_connection_info(f"{sabnzbd.BROWSER_URL}/api?apikey={sabnzbd.cfg.api_key()}")
 
     if pid_path or pid_file:
-        sabnzbd.pid_file(pid_path, pid_file, cherryport)
+        sabnzbd.pid_file(pid_path, pid_file, web_port)
 
     # Stop here in case of fatal errors
     if sabnzbd.NO_DOWNLOADING:
@@ -1493,29 +1452,20 @@ def main():
         for upload_nzb in upload_nzbs:
             sabnzbd.nzbparser.add_nzbfile(upload_nzb)
 
-    # Set URL for browser
-    if enable_https:
-        browser_url = "https://%s:%s%s" % (browserhost, cherryport, sabnzbd.cfg.url_base())
-    else:
-        browser_url = "http://%s:%s%s" % (browserhost, cherryport, sabnzbd.cfg.url_base())
-    sabnzbd.BROWSER_URL = browser_url
-
     if not autorestarted:
-        launch_a_browser(browser_url)
+        launch_a_browser(sabnzbd.BROWSER_URL)
         notifier.send_notification("SABnzbd", T("SABnzbd %s started") % sabnzbd.__version__, "startup")
-        # Now's the time to check for a new version
-        check_latest_version()
     autorestarted = False
 
     # Start SSDP and Bonjour if SABnzbd isn't listening on localhost only
-    if sabnzbd.cfg.enable_broadcast() and not is_localhost(cherryhost):
+    if sabnzbd.cfg.enable_broadcast() and not is_localhost(web_host):
         # Try to find a LAN IP address for SSDP/Bonjour
-        if is_lan_addr(cherryhost):
+        if is_lan_addr(web_host):
             # A specific listening address was configured, use that
-            external_host = cherryhost
+            external_host = web_host
         else:
             # Fall back to the IPv4 address of the LAN interface
-            external_host = localipv4()
+            external_host = local_ipv4()
         logging.debug("Using %s as host address for Bonjour and SSDP", external_host)
 
         # Only broadcast to local network addresses. If local ranges have been defined, further
@@ -1526,13 +1476,13 @@ def main():
             (not sabnzbd.cfg.local_ranges()) or any(ip_in_subnet(external_host, r) for r in sabnzbd.cfg.local_ranges())
         ):
             # Start Bonjour and SSDP
-            sabnzbd.zconfig.set_bonjour(external_host, cherryport)
+            sabnzbd.zconfig.set_bonjour(external_host, web_port)
 
             # Set URL for browser for external hosts
             ssdp_url = "%s://%s:%s%s" % (
                 ("https" if enable_https else "http"),
                 external_host,
-                cherryport,
+                web_port,
                 sabnzbd.cfg.url_base(),
             )
             ssdp.start_ssdp(
@@ -1605,9 +1555,8 @@ def main():
             if hasattr(sys, "frozen"):
                 if sabnzbd.MACOS:
                     # On macOS restart of app instead of embedded python
-                    my_name = sabnzbd.MY_FULLNAME.replace("/Contents/MacOS/SABnzbd", "")
                     my_args = " ".join(sys.argv[1:])
-                    cmd = 'kill -9 %s && open "%s" --args %s' % (os.getpid(), my_name, my_args)
+                    cmd = 'kill -9 %s && open "%s" --args %s' % (os.getpid(), sys.executable, my_args)
                     logging.info("Launching: %s", cmd)
                     os.system(cmd)
                 elif sabnzbd.WIN_SERVICE:
@@ -1791,10 +1740,10 @@ if __name__ == "__main__":
 
         # Initialize the menu
         shared_app = NSApplication.sharedApplication()
-        sabnzbd_menu = SABnzbdDelegate.alloc().init()
-        shared_app.setDelegate_(sabnzbd_menu)
+        sabnzbd.MACOSTRAY = SABnzbdDelegate.alloc().init()
+        shared_app.setDelegate_(sabnzbd.MACOSTRAY)
         # Build the menu
-        sabnzbd_menu.awakeFromNib()
+        sabnzbd.MACOSTRAY.awakeFromNib()
         # Run the main eventloop
         AppHelper.runEventLoop()
     else:
