@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -49,17 +49,11 @@ RENAMES_FILE = "__renames__"
 ATTRIB_FILE = "SABnzbd_attrib"
 REPAIR_REQUEST = "repair-all.sab"
 
-SABYENC_VERSION_REQUIRED = "5.4.4"
+SABCTOOLS_VERSION_REQUIRED = "8.2.5"
 
 DB_HISTORY_VERSION = 1
 DB_HISTORY_NAME = "history%s.db" % DB_HISTORY_VERSION
 
-CONFIG_BACKUP_FILES = [
-    BYTES_FILE_NAME,
-    RSS_FILE_NAME,
-    DB_HISTORY_NAME,
-]
-
 DEF_DOWNLOAD_DIR = os.path.normpath("Downloads/incomplete")
 DEF_COMPLETE_DIR = os.path.normpath("Downloads/complete")
 DEF_ADMIN_DIR = "admin"
@@ -80,16 +74,34 @@ DEF_LOG_ERRFILE = "sabnzbd.error.log"
 DEF_LOG_CHERRY = "cherrypy.log"
 DEF_ARTICLE_CACHE_DEFAULT = "500M"
 DEF_ARTICLE_CACHE_MAX = "1G"
-DEF_TIMEOUT = 60
+DEF_NETWORKING_TIMEOUT = 60
+DEF_NETWORKING_TEST_TIMEOUT = 5
+DEF_NETWORKING_SHORT_TIMEOUT = 3
 DEF_SCANRATE = 5
+DEF_HTTPS_CERT_FILE = "server.cert"
+DEF_HTTPS_KEY_FILE = "server.key"
+DEF_SORTER_RENAME_SIZE = "50M"
 MAX_WARNINGS = 20
 MAX_BAD_ARTICLES = 5
 
+CONFIG_BACKUP_FILES = [
+    BYTES_FILE_NAME,
+    RSS_FILE_NAME,
+    DB_HISTORY_NAME,
+]
+CONFIG_BACKUP_HTTPS = {  # "basename": "associated setting"
+    DEF_HTTPS_CERT_FILE: "https_cert",
+    DEF_HTTPS_KEY_FILE: "https_key",
+    "server.chain": "https_chain",
+}
+
 # Constants affecting download performance
-MIN_DECODE_QUEUE = 10
-LIMIT_DECODE_QUEUE = 100
-DIRECT_WRITE_TRIGGER = 35
-MAX_ASSEMBLER_QUEUE = 5
+MAX_ASSEMBLER_QUEUE = 12
+SOFT_QUEUE_LIMIT = 0.5
+# Percentage of cache to use before adding file to assembler
+ASSEMBLER_WRITE_THRESHOLD = 5
+NNTP_BUFFER_SIZE = int(800 * KIBI)
+NTTP_MAX_BUFFER_SIZE = int(10 * MEBI)
 
 REPAIR_PRIORITY = 3
 FORCE_PRIORITY = 2
@@ -98,9 +110,10 @@ NORMAL_PRIORITY = 0
 LOW_PRIORITY = -1
 DEFAULT_PRIORITY = -100
 PAUSED_PRIORITY = -2
-DUP_PRIORITY = -3
 STOP_PRIORITY = -4
 
+PP_LOOKUP = {0: "", 1: "R", 2: "U", 3: "D"}
+
 INTERFACE_PRIORITIES = {
     FORCE_PRIORITY: "Force",
     REPAIR_PRIORITY: "Repair",
@@ -110,14 +123,15 @@ INTERFACE_PRIORITIES = {
 }
 
 STAGES = {
-    "Source": 0,
-    "Download": 1,
-    "Servers": 2,
-    "Repair": 3,
-    "Filejoin": 4,
-    "Unpack": 5,
-    "Deobfuscate": 6,
-    "Script": 7,
+    "RSS": 0,
+    "Source": 1,
+    "Download": 2,
+    "Servers": 3,
+    "Repair": 4,
+    "Filejoin": 5,
+    "Unpack": 6,
+    "Deobfuscate": 7,
+    "Script": 8,
 }
 
 VALID_ARCHIVES = (".zip", ".rar", ".7z")
@@ -131,6 +145,8 @@ IGNORED_MOVIE_FOLDERS = ("video_ts", "audio_ts", "bdmv")
 EXCLUDED_GUESSIT_PROPERTIES = [
     "part",
 ]
+GUESSIT_PART_INDICATORS = ("cd", "part")
+GUESSIT_SORT_TYPES = {0: "all", 1: "tv", 2: "date", 3: "movie", 4: "unknown"}
 
 
 class Status:
@@ -150,4 +166,19 @@ class Status:
     RUNNING = "Running"  # PP: User's post processing script is running
     VERIFYING = "Verifying"  # PP: Job is being verified (by par2)
     DELETED = "Deleted"  # Q:  Job has been deleted (and is almost gone)
-    PROP = "Propagating"  # Q:  Delayed download
+    PROPAGATING = "Propagating"  # Q:  Delayed download
+
+
+class DuplicateStatus:
+    DUPLICATE = "Duplicate"  # Simple duplicate
+    DUPLICATE_ALTERNATIVE = "Duplicate Alternative"  # Alternative duplicate for a queued job
+    SMART_DUPLICATE = "Smart Duplicate"  # Simple Series duplicate
+    SMART_DUPLICATE_ALTERNATIVE = "Smart Duplicate Alternative"  # Alternative duplicate for a queued job
+    DUPLICATE_IGNORED = "Duplicate Ignored"
+
+
+class AddNzbFileResult:
+    RETRY = "Retry"  # File could not be read
+    ERROR = "Error"  # Rejected as duplicate, by pre-queue script or other failure to process file
+    OK = "OK"  # Added to queue
+    NO_FILES_FOUND = "No files found"  # Malformed or might not be an NZB file
