@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -63,7 +63,7 @@ class BadUu(Exception):
     pass
 
 
-def decode(article: Article, raw_data: bytearray):
+def decode(article: Article, data_view: memoryview):
     decoded_data = None
     nzo = article.nzf.nzo
     art_id = article.article
@@ -79,9 +79,9 @@ def decode(article: Article, raw_data: bytearray):
             logging.debug("Decoding %s", art_id)
 
         if article.nzf.type == "uu":
-            decoded_data = decode_uu(article, raw_data)
+            decoded_data = decode_uu(article, bytes(data_view))
         else:
-            decoded_data = decode_yenc(article, raw_data)
+            decoded_data = decode_yenc(article, data_view)
 
         article_success = True
 
@@ -112,23 +112,23 @@ def decode(article: Article, raw_data: bytearray):
 
     except (BadYenc, ValueError):
         # Handles precheck and badly formed articles
-        if nzo.precheck and raw_data and raw_data.startswith(b"223 "):
+        if nzo.precheck and data_view and data_view[:4] == b"223 ":
             # STAT was used, so we only get a status code
             article_success = True
         else:
             # Try uu-decoding
-            if (not nzo.precheck) and article.nzf.type != "yenc":
+            if not nzo.precheck and article.nzf.type != "yenc":
                 try:
-                    decoded_data = decode_uu(article, raw_data)
+                    decoded_data = decode_uu(article, bytes(data_view))
                     logging.debug("Found uu-encoded article %s in job %s", art_id, nzo.final_name)
                     article_success = True
-                except Exception:
+                except:
                     pass
             # Only bother with further checks if uu-decoding didn't work out
             if not article_success:
                 # Convert the first 2000 bytes of raw socket data to article lines,
                 # and examine the headers (for precheck) or body (for download).
-                for line in raw_data[:2000].split(b"\r\n"):
+                for line in bytes(data_view[:2000]).split(b"\r\n"):
                     lline = line.lower()
                     if lline.startswith(b"message-id:"):
                         article_success = True
@@ -170,9 +170,16 @@ def decode(article: Article, raw_data: bytearray):
     sabnzbd.NzbQueue.register_article(article, article_success)
 
 
-def decode_yenc(article: Article, data: bytearray) -> bytearray:
+def decode_yenc(article: Article, data_view: memoryview) -> bytearray:
     # Let SABCTools do all the heavy lifting
-    yenc_filename, article.data_begin, article.data_size, crc_correct = sabctools.yenc_decode(data)
+    (
+        decoded_data,
+        yenc_filename,
+        article.file_size,
+        article.data_begin,
+        article.data_size,
+        crc_correct,
+    ) = sabctools.yenc_decode(data_view)
 
     nzf = article.nzf
     # Assume it is yenc
@@ -182,7 +189,7 @@ def decode_yenc(article: Article, data: bytearray) -> bytearray:
     if not nzf.filename_checked and yenc_filename:
         # Set the md5-of-16k if this is the first article
         if article.lowest_partnum:
-            nzf.md5of16k = hashlib.md5(data[:16384]).digest()
+            nzf.md5of16k = hashlib.md5(decoded_data[:16384]).digest()
 
         # Try the rename, even if it's not the first article
         # For example when the first article was missing
@@ -191,18 +198,18 @@ def decode_yenc(article: Article, data: bytearray) -> bytearray:
     # CRC check
     if crc_correct is None:
         logging.info("CRC Error in %s", article.article)
-        raise BadData(data)
+        raise BadData(decoded_data)
 
     article.crc32 = crc_correct
 
-    return data
+    return decoded_data
 
 
-def decode_uu(article: Article, raw_data: bytearray) -> bytes:
+def decode_uu(article: Article, raw_data: bytes) -> bytes:
     """Try to uu-decode an article. The raw_data may or may not contain headers.
     If there are headers, they will be separated from the body by at least one
     empty line. In case of no headers, the first line seems to always be the nntp
-    response code (222) directly followed by the msg body."""
+    response code (220/222) directly followed by the msg body."""
     if not raw_data:
         logging.debug("No data to decode")
         raise BadUu
@@ -222,10 +229,10 @@ def decode_uu(article: Article, raw_data: bytearray) -> bytes:
     # Try to find an empty line separating the body from headers or response
     # code and set the expected payload start to the next line.
     try:
-        uu_start = raw_data[:limit].index(bytearray(b"")) + 1
+        uu_start = raw_data[:limit].index(b"") + 1
     except ValueError:
         # No empty line, look for a response code instead
-        if raw_data[0].startswith(b"222 "):
+        if raw_data[0].startswith(b"220 ") or raw_data[0].startswith(b"222 "):
             uu_start = 1
         else:
             # Invalid data?
