@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2023 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,26 +19,23 @@
 sabnzbd.downloader - download engine
 """
 
-import time
 import select
 import logging
-from math import ceil
-from threading import Thread, RLock
-import random
+from threading import Thread, RLock, current_thread
 import socket
 import sys
 import ssl
+import time
+from datetime import date
 from typing import List, Dict, Optional, Union, Set
-import concurrent
-from concurrent.futures import ThreadPoolExecutor, Future
 
 import sabnzbd
-from sabnzbd.decorators import synchronized, NzbQueueLocker, DOWNLOADER_CV
+from sabnzbd.decorators import synchronized, NzbQueueLocker, DOWNLOADER_CV, DOWNLOADER_LOCK
 from sabnzbd.newswrapper import NewsWrapper, NNTPPermanentError
 import sabnzbd.config as config
 import sabnzbd.cfg as cfg
-from sabnzbd.misc import from_units, get_server_addrinfo, helpful_warning, int_conv
-from sabnzbd.utils.happyeyeballs import happyeyeballs
+from sabnzbd.misc import from_units, helpful_warning, int_conv, MultiAddQueue
+from sabnzbd.happyeyeballs import happyeyeballs, AddrInfo
 from sabnzbd.constants import SOFT_QUEUE_LIMIT
 
 
@@ -62,7 +59,6 @@ _ARTICLE_PREFETCH = 20
 _DEFAULT_CHUNK_SIZE = 32768
 
 TIMER_LOCK = RLock()
-DOWNLOADER_LOCK = RLock()
 
 
 class Server:
@@ -84,7 +80,6 @@ class Server:
         "required",
         "optional",
         "retention",
-        "send_group",
         "username",
         "password",
         "busy_threads",
@@ -95,7 +90,7 @@ class Server:
         "bad_cons",
         "errormsg",
         "warning",
-        "info",
+        "addrinfo",
         "ssl_info",
         "request",
         "have_body",
@@ -115,7 +110,6 @@ class Server:
         use_ssl,
         ssl_verify,
         ssl_ciphers,
-        send_group,
         username=None,
         password=None,
         required=False,
@@ -138,20 +132,18 @@ class Server:
         self.required: bool = required
         self.optional: bool = optional
         self.retention: int = retention
-        self.send_group: bool = send_group
-
         self.username: Optional[str] = username
         self.password: Optional[str] = password
 
-        self.busy_threads: List[NewsWrapper] = []
+        self.busy_threads: Set[NewsWrapper] = set()
         self.next_busy_threads_check: float = 0
-        self.idle_threads: List[NewsWrapper] = []
+        self.idle_threads: Set[NewsWrapper] = set()
         self.next_article_search: float = 0
         self.active: bool = True
         self.bad_cons: int = 0
         self.errormsg: str = ""
         self.warning: str = ""
-        self.info: Optional[List] = None  # Will hold getaddrinfo() list
+        self.addrinfo: Union[AddrInfo, None, bool] = None  # Will hold fasted address information
         self.ssl_info: str = ""  # Will hold the type and cipher of SSL connection
         self.request: bool = False  # True if a getaddrinfo() request is pending
         self.have_body: bool = True  # Assume server has "BODY", until proven otherwise
@@ -162,46 +154,11 @@ class Server:
         if threads:
             # Initialize threads
             for i in range(threads):
-                self.idle_threads.append(NewsWrapper(self, i + 1))
+                self.idle_threads.add(NewsWrapper(self, i + 1))
 
             # Tell the BPSMeter about this server
             sabnzbd.BPSMeter.init_server_stats(self.id)
 
-    @property
-    def hostip(self) -> str:
-        """In case a server still has active connections, we use the same IP again
-        If new connection then based on value of load_balancing() and self.info:
-        0 - return the first entry, so all threads use the same IP
-        1 - and self.info has more than 1 entry (read: IP address): Return a random entry from the possible IPs
-        2 - and self.info has more than 1 entry (read: IP address): Return the quickest IP based on the happyeyeballs algorithm
-        In case of problems: return the host name itself
-        """
-        # Check if already a successful ongoing connection
-        if self.busy_threads and self.busy_threads[0].nntp:
-            # Re-use that IP
-            logging.debug("%s: Re-using address %s", self.host, self.busy_threads[0].nntp.host)
-            return self.busy_threads[0].nntp.host
-
-        # Determine IP
-        ip = self.host
-        if self.info:
-            # Check this first so we can fall back to default method if it returns None.
-            if len(self.info) > 1 and cfg.load_balancing() == 2:
-                # RFC6555 / Happy Eyeballs:
-                ip = happyeyeballs(self.host, port=self.port)
-                if not ip:
-                    # nothing returned, so there was a connection problem
-                    logging.debug("%s: No successful IP connection was possible using happyeyeballs", self.host)
-            if not ip or cfg.load_balancing() == 0 or len(self.info) == 1:
-                # Just return the first one, so all next threads use the same IP
-                ip = self.info[0][4][0]
-            elif cfg.load_balancing() == 1:
-                # Return a random entry from the possible IPs
-                rnd = random.randint(0, len(self.info) - 1)
-                ip = self.info[rnd][4][0]
-        logging.debug("%s: Connecting to address %s", self.host, ip)
-        return ip
-
     def deactivate(self):
         """Deactivate server and reset queued articles"""
         self.active = False
@@ -211,8 +168,8 @@ class Server:
         """Remove all connections from server"""
         for nw in self.idle_threads:
             sabnzbd.Downloader.remove_socket(nw)
-            nw.hard_reset(send_quit=True)
-        self.idle_threads = []
+            nw.hard_reset()
+        self.idle_threads = set()
 
     @synchronized(DOWNLOADER_LOCK)
     def get_article(self):
@@ -241,25 +198,31 @@ class Server:
     def reset_article_queue(self):
         logging.debug("Resetting article queue for %s", self)
         for article in self.article_queue:
-            sabnzbd.NzbQueue.reset_try_lists(article, remove_fetcher_from_trylist=False)
+            sabnzbd.NzbQueue.reset_try_lists(article)
         self.article_queue = []
 
-    def request_info(self):
-        """Launch async request to resolve server address.
-        getaddrinfo() can be very slow. In some situations this can lead
-        to delayed starts and timeouts on connections.
+    def request_addrinfo(self):
+        """Launch async request to resolve server address and perform Happy Eyeballs.
+        In some situations this can be slow and result in delayed starts and timeouts on connections.
         Because of this, the results will be cached in the server object."""
         if not self.request:
             self.request = True
-            Thread(target=self._request_info_internal).start()
+            Thread(target=self.request_addrinfo_blocking).start()
 
-    def _request_info_internal(self):
-        """Async attempt to run getaddrinfo() for specified server"""
+    def request_addrinfo_blocking(self):
+        """Blocking attempt to run getaddrinfo() and Happy Eyeballs for specified server"""
         logging.debug("Retrieving server address information for %s", self.host)
-        self.info = get_server_addrinfo(self.host, self.port)
-        if not self.info:
+
+        # Disable IPV6 if desired
+        family = socket.AF_UNSPEC
+        if not cfg.ipv6_servers():
+            family = socket.AF_INET
+
+        self.addrinfo = happyeyeballs(self.host, self.port, self.timeout, family)
+        if not self.addrinfo:
             self.bad_cons += self.threads
-            self.info = False
+            # Notify next call to maybe_block_server
+            self.addrinfo = False
         else:
             self.bad_cons = 0
         self.request = False
@@ -279,8 +242,6 @@ class Downloader(Thread):
         "bandwidth_limit",
         "bandwidth_perc",
         "sleep_time",
-        "recv_pool",
-        "recv_threads",
         "paused_for_postproc",
         "shutdown",
         "server_restarts",
@@ -290,7 +251,6 @@ class Downloader(Thread):
         "timers",
         "last_max_chunk_size",
         "max_chunk_size",
-        "process_tasks",
     )
 
     def __init__(self, paused=False):
@@ -317,12 +277,6 @@ class Downloader(Thread):
         self.last_max_chunk_size: int = 0
         self.max_chunk_size: int = _DEFAULT_CHUNK_SIZE
 
-        self.recv_threads: int = cfg.receive_threads()
-        self.recv_pool: Optional[ThreadPoolExecutor] = ThreadPoolExecutor(self.recv_threads)
-        logging.debug("Receive threads: %s", self.recv_threads)
-
-        self.process_tasks: Set[Future[NewsWrapper, int]] = set()
-
         self.paused_for_postproc: bool = False
         self.shutdown: bool = False
 
@@ -366,7 +320,6 @@ class Downloader(Thread):
             required = srv.required()
             optional = srv.optional()
             retention = int(srv.retention() * 24 * 3600)  # days ==> seconds
-            send_group = srv.send_group()
             create = True
 
         if oldserver:
@@ -393,7 +346,6 @@ class Downloader(Thread):
                     ssl,
                     ssl_verify,
                     ssl_ciphers,
-                    send_group,
                     username,
                     password,
                     required,
@@ -516,7 +468,7 @@ class Downloader(Thread):
 
     def maybe_block_server(self, server: Server):
         # Was it resolving problem?
-        if server.info is False:
+        if server.addrinfo is False:
             # Warn about resolving issues
             errormsg = T("Cannot connect to server %s [%s]") % (server.host, T("Server name does not resolve"))
             if server.errormsg != errormsg:
@@ -543,38 +495,29 @@ class Downloader(Thread):
             self.plan_server(server, _PENALTY_TIMEOUT)
 
             # Remove all connections to server
-            for nw in server.idle_threads + server.busy_threads:
-                self.__reset_nw(nw, "forcing disconnect", warn=False, wait=False, retry_article=False, send_quit=False)
+            for nw in server.idle_threads | server.busy_threads:
+                self.__reset_nw(nw, "Forcing disconnect", warn=False, wait=False, retry_article=False)
 
             # Make sure server address resolution is refreshed
-            server.info = None
+            server.addrinfo = None
 
-    def decode(self, article, raw_data: Optional[bytearray] = None):
+    @staticmethod
+    def decode(article, data_view: Optional[memoryview] = None):
         """Decode article"""
         # Article was requested and fetched, update article stats for the server
         sabnzbd.BPSMeter.register_server_article_tried(article.fetcher.id)
 
         # Handle broken articles directly
-        if not raw_data:
+        if not data_view:
             if not article.search_new_server():
-                sabnzbd.NzbQueue.register_article(article, success=False)
                 article.nzf.nzo.increase_bad_articles_counter("missing_articles")
+                sabnzbd.NzbQueue.register_article(article, success=False)
             return
 
         # Decode and send to article cache
-        sabnzbd.decoder.decode(article, raw_data)
+        sabnzbd.decoder.decode(article, data_view)
 
     def run(self):
-        # First check IPv6 connectivity
-        sabnzbd.EXTERNAL_IPV6 = sabnzbd.misc.test_ipv6()
-        logging.debug("External IPv6 test result: %s", sabnzbd.EXTERNAL_IPV6)
-
-        logging.debug("switchinterval = %s", sys.getswitchinterval())
-
-        # Then we check SSL certificate checking
-        sabnzbd.CERTIFICATE_VALIDATION = sabnzbd.misc.test_cert_checking()
-        logging.debug("SSL verification test: %s", sabnzbd.CERTIFICATE_VALIDATION)
-
         # Warn if there are servers defined, but none are valid
         if config.get_servers() and not self.servers:
             logging.warning(T("There are no active servers!"))
@@ -587,6 +530,13 @@ class Downloader(Thread):
         # Check server expiration dates
         check_server_expiration()
 
+        # Initialize queue and threads
+        process_nw_queue = MultiAddQueue()
+        for _ in range(cfg.receive_threads()):
+            # Started as daemon, so we don't need any shutdown logic in the worker
+            # The Downloader code will make sure shutdown is handled gracefully
+            Thread(target=self.process_nw_worker, args=(self.read_fds, process_nw_queue), daemon=True).start()
+
         # Catch all errors, just in case
         try:
             while 1:
@@ -598,18 +548,18 @@ class Downloader(Thread):
 
                 for server in self.servers:
                     # Skip this server if there's no point searching for new stuff to do
-                    if not server.busy_threads and server.next_article_search > now:
+                    if server.addrinfo and not server.busy_threads and server.next_article_search > now:
                         continue
 
                     if server.next_busy_threads_check < now:
                         server.next_busy_threads_check = now + _SERVER_CHECK_DELAY
-                        for nw in server.busy_threads[:]:
+                        for nw in server.busy_threads.copy():
                             if (nw.nntp and nw.nntp.error_msg) or (nw.timeout and now > nw.timeout):
                                 if nw.nntp and nw.nntp.error_msg:
                                     # Already showed error
                                     self.__reset_nw(nw)
                                 else:
-                                    self.__reset_nw(nw, "timed out", warn=True)
+                                    self.__reset_nw(nw, "Timed out", warn=True)
                                 server.bad_cons += 1
                                 self.maybe_block_server(server)
 
@@ -635,18 +585,18 @@ class Downloader(Thread):
                     ):
                         continue
 
-                    for nw in server.idle_threads[:]:
+                    for nw in server.idle_threads.copy():
                         if nw.timeout:
                             if now < nw.timeout:
                                 continue
                             else:
                                 nw.timeout = None
 
-                        if not server.info:
+                        if not server.addrinfo:
                             # Only request info if there's stuff in the queue
                             if not sabnzbd.NzbQueue.is_empty():
                                 self.maybe_block_server(server)
-                                server.request_info()
+                                server.request_addrinfo()
                             break
 
                         nw.article = server.get_article()
@@ -654,7 +604,7 @@ class Downloader(Thread):
                             break
 
                         server.idle_threads.remove(nw)
-                        server.busy_threads.append(nw)
+                        server.busy_threads.add(nw)
 
                         if nw.connected:
                             self.__request_article(nw)
@@ -669,18 +619,16 @@ class Downloader(Thread):
                                     server.host,
                                     sys.exc_info()[1],
                                 )
-                                self.__reset_nw(nw, "failed to initialize", warn=True)
+                                self.__reset_nw(nw, "Failed to initialize", warn=True)
 
                 if self.force_disconnect or self.shutdown:
                     for server in self.servers:
-                        for nw in server.idle_threads + server.busy_threads:
+                        for nw in server.idle_threads | server.busy_threads:
                             # Send goodbye if we have open socket
                             if nw.nntp:
-                                self.__reset_nw(
-                                    nw, "forcing disconnect", wait=False, count_article_try=False, send_quit=True
-                                )
+                                self.__reset_nw(nw, "Forcing disconnect", wait=False, count_article_try=False)
                         # Make sure server address resolution is refreshed
-                        server.info = None
+                        server.addrinfo = None
                         server.reset_article_queue()
                     self.force_disconnect = False
 
@@ -707,7 +655,7 @@ class Downloader(Thread):
                 else:
                     read = []
                     BPSMeter.reset()
-                    time.sleep(1.0)
+                    time.sleep(0.1)
                     self.max_chunk_size = _DEFAULT_CHUNK_SIZE
                     with DOWNLOADER_CV:
                         while (
@@ -719,59 +667,50 @@ class Downloader(Thread):
                             DOWNLOADER_CV.wait()
 
                 if now > next_bpsmeter_update:
+                    # Do not update statistics and check levels every loop
                     BPSMeter.update()
                     next_bpsmeter_update = now + _BPSMETER_UPDATE_DELAY
+                    self.check_assembler_levels()
 
                 if not read:
                     continue
 
-                if self.recv_threads > 1:
-                    # Submit a process_nw task to the pool for every NewWrapper which is readable
-                    for selected in read:
-                        self.process_tasks.add(self.recv_pool.submit(self.process_nw, self.read_fds[selected]))
+                # Submit all readable sockets to be processed and wait for completion
+                process_nw_queue.put_multiple(read)
+                process_nw_queue.join()
 
-                    # Wait for all the tasks to complete
-                    concurrent.futures.wait(self.process_tasks)
-
-                    # Clear task list
-                    self.process_tasks.clear()
-                else:
-                    for selected in read:
-                        self.process_nw(self.read_fds[selected])
-
-                # Check the Assembler queue to see if we need to delay, depending on queue size
-                if (assembler_level := sabnzbd.Assembler.queue_level()) > SOFT_QUEUE_LIMIT:
-                    time.sleep(min((assembler_level - SOFT_QUEUE_LIMIT) / 4, 0.15))
-                    sabnzbd.BPSMeter.delayed_assembler += 1
-                    logged_counter = 0
-
-                    while not self.shutdown and sabnzbd.Assembler.queue_level() >= 1:
-                        # Only log/update once every second, to not waste any CPU-cycles
-                        if not logged_counter % 10:
-                            # Make sure the BPS-meter is updated
-                            sabnzbd.BPSMeter.update()
-
-                            # Update who is delaying us
-                            logging.debug(
-                                "Delayed - %d seconds - Assembler queue: %d",
-                                logged_counter / 10,
-                                sabnzbd.Assembler.queue.qsize(),
-                            )
-
-                        # Wait and update the queue sizes
-                        time.sleep(0.1)
-                        logged_counter += 1
         except:
             logging.error(T("Fatal error in Downloader"), exc_info=True)
 
-    def process_nw(self, nw: NewsWrapper):
-        """Receive data from NewsWrapper and handle response"""
+    def process_nw_worker(self, read_fds: Dict[int, NewsWrapper], nw_queue: MultiAddQueue):
+        """Worker for the daemon thread to process results.
+        Wrapped in try/except because in case of an exception, logging
+        might get lost and the queue.join() would block forever."""
         try:
-            bytes_received, done = nw.recv_chunk()
+            logging.debug("Starting Downloader receive thread: %s", current_thread().name)
+            while True:
+                # The read_fds is passed by reference, so we can access its items!
+                self.process_nw(read_fds[nw_queue.get()])
+                nw_queue.task_done()
+        except:
+            # We cannot break out of the Downloader from here, so just pause
+            logging.error(T("Fatal error in Downloader"), exc_info=True)
+            self.pause()
+
+    def process_nw(self, nw: NewsWrapper):
+        """Receive data from a NewsWrapper and handle the response"""
+        try:
+            bytes_received, end_of_line, article_done = nw.recv_chunk()
         except ssl.SSLWantReadError:
             return
-        except:
-            self.__reset_nw(nw, "server closed connection", wait=False)
+        except (ConnectionError, ConnectionAbortedError):
+            # The ConnectionAbortedError is also thrown by sabctools in case of fatal SSL-layer problems
+            self.__reset_nw(nw, "Server closed connection", wait=False)
+            return
+        except BufferError:
+            # The BufferError is thrown when exceeding maximum buffer size
+            # Make sure to discard the article
+            self.__reset_nw(nw, "Maximum data buffer size exceeded", wait=False, retry_article=False)
             return
 
         article = nw.article
@@ -781,8 +720,9 @@ class Downloader(Thread):
             sabnzbd.BPSMeter.update(server.id, bytes_received)
             if bytes_received > self.last_max_chunk_size:
                 self.last_max_chunk_size = bytes_received
-            # Update statistics
-            if done:
+            # Update statistics only when we fetched a whole article
+            # The side effect is that we don't count things like article-not-available messages
+            if article_done:
                 article.nzf.nzo.update_download_stats(sabnzbd.BPSMeter.bps, server.id, nw.data_position)
             # Check speedlimit
             if (
@@ -794,7 +734,13 @@ class Downloader(Thread):
                     time.sleep(0.01)
                     sabnzbd.BPSMeter.update()
 
-        if nw.status_code != 222 and not done:
+        # If we are not at the end of a line, more data will follow
+        if not end_of_line:
+            return
+
+        # Response code depends on request command:
+        # 220 = ARTICLE, 222 = BODY
+        if nw.status_code not in (220, 222) and not article_done:
             if not nw.connected or nw.status_code == 480:
                 if not self.__finish_connect_nw(nw):
                     return
@@ -803,17 +749,11 @@ class Downloader(Thread):
                     self.__request_article(nw)
 
             elif nw.status_code == 223:
-                done = True
+                article_done = True
                 logging.debug("Article <%s> is present", article.article)
 
-            elif nw.status_code == 211:
-                logging.debug("group command ok -> %s", nw.nntp_msg)
-                nw.group = nw.article.nzf.nzo.group
-                nw.reset_data_buffer()
-                self.__request_article(nw)
-
-            elif nw.status_code in (411, 423, 430):
-                done = True
+            elif nw.status_code in (411, 423, 430, 451):
+                article_done = True
                 logging.debug(
                     "Thread %s@%s: Article %s missing (error=%s)",
                     nw.thrdnum,
@@ -835,13 +775,28 @@ class Downloader(Thread):
                 nw.reset_data_buffer()
                 self.__request_article(nw)
 
-        if done:
+            else:
+                # Don't warn for (internal) server errors during downloading
+                if nw.status_code not in (400, 502, 503):
+                    logging.warning(
+                        T("%s@%s: Received unknown status code %s for article %s"),
+                        nw.thrdnum,
+                        nw.server.host,
+                        nw.status_code,
+                        article.article,
+                    )
+
+                # Ditch this thread, we don't know what data we got now so the buffer can be bad
+                self.__reset_nw(nw, f"Server error or unknown status code: {nw.status_code}", wait=False)
+                return
+
+        if article_done:
             # Successful data, clear "bad" counter
             server.bad_cons = 0
             server.errormsg = server.warning = ""
 
             # Decode
-            self.decode(article, nw.get_data_buffer())
+            self.decode(article, nw.data_view[: nw.data_position])
 
             if sabnzbd.LOG_ALL:
                 logging.debug("Thread %s@%s: %s done", nw.thrdnum, server.host, article.article)
@@ -861,10 +816,34 @@ class Downloader(Thread):
                     self.__request_article(nw)
                     return
 
-            with DOWNLOADER_LOCK:
-                server.busy_threads.remove(nw)
-                server.idle_threads.append(nw)
-                self.remove_socket(nw)
+            # Make socket available again
+            server.busy_threads.discard(nw)
+            server.idle_threads.add(nw)
+            self.remove_socket(nw)
+
+    def check_assembler_levels(self):
+        """Check the Assembler queue to see if we need to delay, depending on queue size"""
+        if (assembler_level := sabnzbd.Assembler.queue_level()) > SOFT_QUEUE_LIMIT:
+            time.sleep(min((assembler_level - SOFT_QUEUE_LIMIT) / 4, 0.15))
+            sabnzbd.BPSMeter.delayed_assembler += 1
+            logged_counter = 0
+
+            while not self.shutdown and sabnzbd.Assembler.queue_level() >= 1:
+                # Only log/update once every second, to not waste any CPU-cycles
+                if not logged_counter % 10:
+                    # Make sure the BPS-meter is updated
+                    sabnzbd.BPSMeter.update()
+
+                    # Update who is delaying us
+                    logging.debug(
+                        "Delayed - %d seconds - Assembler queue: %d",
+                        logged_counter / 10,
+                        sabnzbd.Assembler.queue.qsize(),
+                    )
+
+                # Wait and update the queue sizes
+                time.sleep(0.1)
+                logged_counter += 1
 
     @synchronized(DOWNLOADER_LOCK)
     def __finish_connect_nw(self, nw: NewsWrapper) -> bool:
@@ -886,7 +865,7 @@ class Downloader(Thread):
                 errormsg = T("Too many connections to server %s [%s]") % (server.host, error.msg)
                 if server.active:
                     # Don't count this for the tries (max_art_tries) on this server
-                    self.__reset_nw(nw, send_quit=True)
+                    self.__reset_nw(nw)
                     self.plan_server(server, _PENALTY_TOOMANY)
                     server.threads -= 1
             elif error.code in (502, 481, 482) and clues_too_many_ip(error.msg):
@@ -919,6 +898,13 @@ class Downloader(Thread):
                 errormsg = T("Cannot connect to server %s [%s]") % (server.host, error.msg)
                 penalty = _PENALTY_UNKNOWN
                 block = True
+
+            # Set error for server and warn user if it was first time thrown
+            if errormsg and server.active and server.errormsg != errormsg:
+                server.errormsg = errormsg
+                logging.warning(errormsg)
+
+            # Take action on the problem
             if block or (penalty and server.optional):
                 retry_article = False
                 if server.active:
@@ -930,20 +916,16 @@ class Downloader(Thread):
                         if penalty and (block or server.optional):
                             self.plan_server(server, penalty)
                 # Note that the article is discard for this server if the server is not required
-                self.__reset_nw(nw, retry_article=retry_article, send_quit=True)
-
-            # Set error for server and warn user if it was first time thrown
-            if errormsg and server.active and server.errormsg != errormsg:
-                server.errormsg = errormsg
-                logging.warning(errormsg)
+                self.__reset_nw(nw, retry_article=retry_article)
             return False
-        except:
+        except Exception as err:
             logging.error(
                 T("Connecting %s@%s failed, message=%s"),
                 nw.thrdnum,
                 nw.server.host,
-                nw.nntp_msg,
+                err,
             )
+            logging.info("Traceback: ", exc_info=True)
             # No reset-warning needed, above logging is sufficient
             self.__reset_nw(nw, retry_article=False)
         return True
@@ -957,7 +939,6 @@ class Downloader(Thread):
         wait: bool = True,
         count_article_try: bool = True,
         retry_article: bool = True,
-        send_quit: bool = False,
     ):
         # Some warnings are errors, and not added as server.warning
         if warn and reset_msg:
@@ -967,10 +948,8 @@ class Downloader(Thread):
             logging.debug("Thread %s@%s: %s", nw.thrdnum, nw.server.host, reset_msg)
 
         # Make sure this NewsWrapper is in the idle threads
-        if nw in nw.server.busy_threads:
-            nw.server.busy_threads.remove(nw)
-        if nw not in nw.server.idle_threads:
-            nw.server.idle_threads.append(nw)
+        nw.server.busy_threads.discard(nw)
+        nw.server.idle_threads.add(nw)
 
         # Make sure it is not in the readable sockets
         self.remove_socket(nw)
@@ -986,42 +965,30 @@ class Downloader(Thread):
                 self.decode(nw.article)
                 nw.article.tries = 0
             else:
-                # Retry again with the same server
-                logging.debug(
-                    "Re-adding article %s from %s to server %s",
-                    nw.article.article,
-                    nw.article.nzf.filename,
-                    nw.article.fetcher,
-                )
-                nw.article.fetcher.article_queue.append(nw.article)
+                # Allow all servers again on this server
+                # Do not use the article_queue, as the server could already have been disabled when we get here!
+                sabnzbd.NzbQueue.reset_try_lists(nw.article)
 
         # Reset connection object
-        nw.hard_reset(wait, send_quit=send_quit)
+        nw.hard_reset(wait)
 
         # Empty SSL info, it might change on next connect
         nw.server.ssl_info = ""
 
     def __request_article(self, nw: NewsWrapper):
         try:
-            nzo = nw.article.nzf.nzo
-            if nw.server.send_group and nzo.group != nw.group:
-                group = nzo.group
-                if sabnzbd.LOG_ALL:
-                    logging.debug("Thread %s@%s: GROUP <%s>", nw.thrdnum, nw.server.host, group)
-                nw.send_group(group)
-            else:
-                if sabnzbd.LOG_ALL:
-                    logging.debug("Thread %s@%s: BODY %s", nw.thrdnum, nw.server.host, nw.article.article)
-                nw.body()
+            if sabnzbd.LOG_ALL:
+                logging.debug("Thread %s@%s: BODY %s", nw.thrdnum, nw.server.host, nw.article.article)
+            nw.body()
             # Mark as ready to be read
             self.add_socket(nw.nntp.fileno, nw)
         except socket.error as err:
             logging.info("Looks like server closed connection: %s", err)
-            self.__reset_nw(nw, "server broke off connection", warn=True, send_quit=False)
+            self.__reset_nw(nw, "Server broke off connection", warn=True)
         except:
             logging.error(T("Suspect error in downloader"))
             logging.info("Traceback: ", exc_info=True)
-            self.__reset_nw(nw, "server broke off connection", warn=True, send_quit=False)
+            self.__reset_nw(nw, "Server broke off connection", warn=True)
 
     # ------------------------------------------------------------------------------
     # Timed restart of servers admin.
@@ -1153,9 +1120,12 @@ def check_server_expiration():
     """Check if user should get warning about server date expiration"""
     for server in config.get_servers().values():
         if server.expire_date():
-            days_to_expire = ceil(
-                (time.mktime(time.strptime(server.expire_date(), "%Y-%m-%d")) - time.time()) / (60 * 60 * 24)
-            )
+            try:
+                days_to_expire = (date.fromisoformat(server.expire_date()) - date.today()).days
+            except ValueError:
+                # In case of invalid date, just warn
+                days_to_expire = 0
+
             # Notify from 5 days in advance
             if days_to_expire < 6:
                 logging.warning(T("Server %s is expiring in %s day(s)"), server.displayname(), days_to_expire)
