@@ -50,10 +50,10 @@ from sabnzbd.misc import (
     is_lan_addr,
     is_local_addr,
     is_loopback_addr,
-    helpful_warning,
     recursive_html_escape,
     is_none,
     get_cpu_name,
+    clean_comma_separated_list,
 )
 from sabnzbd.happyeyeballs import happyeyeballs
 from sabnzbd.filesystem import (
@@ -69,7 +69,6 @@ import sabnzbd.config as config
 import sabnzbd.cfg as cfg
 import sabnzbd.notifier as notifier
 import sabnzbd.newsunpack
-from sabnzbd.utils.servertests import test_nntp_server_dict
 import sabnzbd.utils.ssdp
 from sabnzbd.constants import (
     DEF_STD_CONFIG,
@@ -81,7 +80,7 @@ from sabnzbd.constants import (
     GUESSIT_SORT_TYPES,
     VALID_NZB_FILES,
     VALID_ARCHIVES,
-    DEF_TIMEOUT,
+    DEF_NETWORKING_TEST_TIMEOUT,
 )
 from sabnzbd.lang import list_languages
 from sabnzbd.api import (
@@ -211,11 +210,14 @@ def check_access(access_type: int = 4, warn_user: bool = False) -> bool:
     is_allowed = is_loopback_addr(remote_ip) or is_local_addr(remote_ip)
 
     # Never check the XFF header unless access would have been granted based on the remote IP alone!
-    if is_allowed and cfg.verify_xff_header() and (xff_header := cherrypy.request.headers.get("X-Forwarded-For")):
-        xff_ips = [ip.strip() for ip in xff_header.split(",")]
+    if (
+        is_allowed
+        and cfg.verify_xff_header()
+        and (xff_ips := clean_comma_separated_list(cherrypy.request.headers.get("X-Forwarded-For")))
+    ):
         is_allowed = all(is_local_addr(ip) or is_loopback_addr(ip) for ip in xff_ips)
         if not is_allowed:
-            logging.debug("Denying access based on X-Forwarded-For header '%s'", xff_header)
+            logging.debug("Denying access based on X-Forwarded-For IPs '%s'", xff_ips)
 
     if not is_allowed and warn_user:
         log_warning_and_ip(T("Refused connection from:"))
@@ -432,6 +434,7 @@ class MainPage:
 
             info["cpumodel"] = get_cpu_name()
             info["cpusimd"] = sabnzbd.decoder.SABCTOOLS_SIMD
+            info["docker"] = "Docker" if sabnzbd.DOCKER else ""
 
             # Have logout only with HTML and if inet=5, only when we are external
             info["have_logout"] = (
@@ -575,7 +578,7 @@ class Wizard:
 def get_access_info():
     """Build up a list of url's that sabnzbd can be accessed from"""
     # Access_url is used to provide the user a link to SABnzbd depending on the host
-    cherryhost = cfg.cherryhost()
+    web_host = cfg.web_host()
     host = socket.gethostname().lower()
     logging.info("hostname is", host)
     socks = [host]
@@ -585,7 +588,7 @@ def get_access_info():
     except:
         addresses = []
 
-    if cherryhost == "0.0.0.0":
+    if web_host == "0.0.0.0":
         # Grab a list of all ips for the hostname
         for addr in addresses:
             address = addr[4][0]
@@ -593,7 +596,7 @@ def get_access_info():
             if ":" not in address and address not in socks:
                 socks.append(address)
         socks.insert(0, "localhost")
-    elif cherryhost == "::":
+    elif web_host == "::":
         # Grab a list of all ips for the hostname
         for addr in addresses:
             address = addr[4][0]
@@ -603,8 +606,8 @@ def get_access_info():
                 if address not in socks:
                     socks.append(address)
         socks.insert(0, "localhost")
-    elif cherryhost:
-        socks = [cherryhost]
+    elif web_host:
+        socks = [web_host]
 
     # Add the current requested URL as the base
     access_url = urllib.parse.urljoin(cherrypy.request.base, cfg.url_base())
@@ -615,9 +618,9 @@ def get_access_info():
             if cfg.enable_https() and cfg.https_port():
                 url = "https://%s:%s%s" % (sock, cfg.https_port(), cfg.url_base())
             elif cfg.enable_https():
-                url = "https://%s:%s%s" % (sock, cfg.cherryport(), cfg.url_base())
+                url = "https://%s:%s%s" % (sock, cfg.web_port(), cfg.url_base())
             else:
-                url = "http://%s:%s%s" % (sock, cfg.cherryport(), cfg.url_base())
+                url = "http://%s:%s%s" % (sock, cfg.web_port(), cfg.url_base())
             urls.append(url)
 
     # Return a unique list
@@ -773,7 +776,8 @@ SWITCH_LIST = (
     "quota_day",
     "quota_resume",
     "quota_period",
-    "history_retention",
+    "history_retention_option",
+    "history_retention_number",
     "pre_check",
     "max_art_tries",
     "fail_hopeless_jobs",
@@ -831,6 +835,7 @@ SPECIAL_BOOL_LIST = (
     "preserve_paused_state",
     "no_penalties",
     "ipv6_servers",
+    "ipv6_staging",
     "fast_fail",
     "overwrite_files",
     "enable_par_cleanup",
@@ -853,6 +858,7 @@ SPECIAL_BOOL_LIST = (
     "empty_postproc",
     "new_nzb_on_failure",
     "html_login",
+    "disable_archive",
     "wait_for_dfolder",
     "enable_broadcast",
     "warn_dupl_jobs",
@@ -1079,11 +1085,6 @@ class ConfigServer:
     def saveServer(self, **kwargs):
         return handle_server(kwargs, self.__root)
 
-    @secured_expose(check_api_key=True, check_configlock=True)
-    def testServer(self, **kwargs):
-        _, msg = test_nntp_server_dict(kwargs)
-        return msg
-
     @secured_expose(check_api_key=True, check_configlock=True)
     def delServer(self, **kwargs):
         kwargs["section"] = "servers"
@@ -1144,7 +1145,9 @@ def handle_server(kwargs, root=None, new_svr=False):
         kwargs["connections"] = "1"
 
     if kwargs.get("enable") == "1":
-        if not happyeyeballs(host, int_conv(port), int_conv(kwargs.get("timeout"), default=DEF_TIMEOUT)):
+        if not happyeyeballs(
+            host, int_conv(port), int_conv(kwargs.get("timeout"), default=DEF_NETWORKING_TEST_TIMEOUT)
+        ):
             return badParameterResponse(T('Server address "%s:%s" is not valid.') % (host, port), ajax)
 
     # Default server name is just the host name
@@ -1162,7 +1165,7 @@ def handle_server(kwargs, root=None, new_svr=False):
     if new_svr:
         server = unique_svr_name(server)
 
-    for kw in ("ssl", "send_group", "enable", "required", "optional"):
+    for kw in ("ssl", "enable", "required", "optional"):
         if kw not in kwargs.keys():
             kwargs[kw] = None
     if svr and not new_svr:
@@ -2091,6 +2094,35 @@ NOTIFY_OPTIONS = {
         "pushbullet_prio_other",
         "pushbullet_prio_new_login",
     ),
+    "apprise": (
+        "apprise_enable",
+        "apprise_cats",
+        "apprise_urls",
+        "apprise_target_startup",
+        "apprise_target_startup_enable",
+        "apprise_target_download",
+        "apprise_target_download_enable",
+        "apprise_target_pause_resume",
+        "apprise_target_pause_resume_enable",
+        "apprise_target_pp",
+        "apprise_target_pp_enable",
+        "apprise_target_complete",
+        "apprise_target_complete_enable",
+        "apprise_target_failed",
+        "apprise_target_failed_enable",
+        "apprise_target_disk_full",
+        "apprise_target_disk_full_enable",
+        "apprise_target_warning",
+        "apprise_target_warning_enable",
+        "apprise_target_error",
+        "apprise_target_error_enable",
+        "apprise_target_queue_done",
+        "apprise_target_queue_done_enable",
+        "apprise_target_other",
+        "apprise_target_other_enable",
+        "apprise_target_new_login",
+        "apprise_target_new_login_enable",
+    ),
     "nscript": (
         "nscript_enable",
         "nscript_cats",
@@ -2127,8 +2159,10 @@ class ConfigNotify:
 
         for section in NOTIFY_OPTIONS:
             for option in NOTIFY_OPTIONS[section]:
-                # Use get_string to make sure lists are displayed correctly
-                conf[option] = config.get_config(section, option).get_string()
+                conf[option] = config.get_config(section, option)()
+
+        # Use get_string to make sure lists are displayed correctly
+        conf["email_to"] = cfg.email_to.get_string()
 
         return template_filtered_response(
             file=os.path.join(sabnzbd.WEB_DIR_CONFIG, "config_notify.tmpl"),
